@@ -759,6 +759,8 @@ parse_source <- function(text,
                         c("rankdir", "LR", "graph"),
                         c("outputorder", "edgesfirst", "graph"),
                         c("fixedsize", "false", "node"),
+                        c("font", "arial", "node"),
+                        c("font", "arial", "edge"),
                         c("shape", "box", "node"),
                         c("style", "rounded,filled", "node"),
                         c("color", "#000000", "node"),
